<?php
/*
Plugin Name: API delivery Plug Send
Plugin URI: https://pluginstech.com
Description: delivery api plugsend
Version: 1.0
Author: Plug Send
Author URI: https://pluginstech.com
License: 
License URI: 
*/

// Evitar acesso direto ao arquivo
if (!defined('ABSPATH')) {
    exit;
}

// Classe principal do plugin
class WhatsAppOrderNotifier {
    private static $instance = null;
    private $status_labels = array(
        'new' => 'Pedido Feito',
        'confirmed' => 'Pedido Confirmado',
        'in-delivery' => 'Pedido Enviado',
        'in delivery' => 'Pedido Enviado',
        'done' => 'Pedido Pronto',
        'waiting' => 'Pedido Aguardando',
        'finished' => 'Pedido Finalizado',
        'canceled' => 'Pedido Cancelado'
    );

    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    private function __construct() {
        add_action('admin_menu', array($this, 'add_admin_menu'));
        add_action('admin_init', array($this, 'register_settings'));
        add_action('update_post_meta', array($this, 'handle_status_update'), 10, 4);
        add_action('admin_head', array($this, 'add_admin_styles'));
    }

    // Adiciona os estilos CSS
    public function add_admin_styles() {
        // Verifica se estamos na página do plugin
        $screen = get_current_screen();
        if (strpos($screen->id, 'whatsapp-notifier') === false) {
            return;
        }
        ?>
        <style>
            .whatsapp-notifier-wrap {
                max-width: 1200px;
                margin: 20px auto;
                padding: 25px;
                background: #fff;
                box-shadow: 0 2px 8px rgba(0,0,0,0.1);
                border-radius: 10px;
            }

            .whatsapp-notifier-wrap h1 {
                color: #1d2327;
                font-size: 24px;
                font-weight: 600;
                margin-bottom: 30px;
                padding-bottom: 15px;
                border-bottom: 2px solid #2271b1;
            }

            .whatsapp-notifier-wrap h2 {
                color: #1d2327;
                font-size: 20px;
                font-weight: 500;
                margin: 30px 0 20px;
                padding-left: 10px;
                border-left: 4px solid #2271b1;
            }

            .whatsapp-notifier-wrap .form-table {
                background: #f8f9fa;
                border-radius: 8px;
                padding: 20px;
                margin: 15px 0;
                border: 1px solid #e2e4e7;
            }

            .whatsapp-notifier-wrap .form-table th {
                padding: 20px;
                color: #1d2327;
                font-weight: 500;
                width: 200px;
            }

            .whatsapp-notifier-wrap input[type="text"],
            .whatsapp-notifier-wrap input[type="password"] {
                width: 100%;
                max-width: 400px;
                padding: 10px 15px;
                border: 1px solid #ccd0d4;
                border-radius: 6px;
                font-size: 14px;
                transition: all 0.3s ease;
                background: #fff;
            }

            .whatsapp-notifier-wrap input[type="text"]:focus,
            .whatsapp-notifier-wrap input[type="password"]:focus {
                border-color: #2271b1;
                box-shadow: 0 0 0 1px #2271b1;
                outline: none;
            }

            .whatsapp-notifier-wrap textarea {
                width: 100%;
                min-height: 150px;
                padding: 15px;
                border: 1px solid #ccd0d4;
                border-radius: 6px;
                font-size: 14px;
                line-height: 1.6;
                transition: all 0.3s ease;
                background: #fff;
                resize: vertical;
            }

            .whatsapp-notifier-wrap textarea:focus {
                border-color: #2271b1;
                box-shadow: 0 0 0 1px #2271b1;
                outline: none;
            }

            .whatsapp-notifier-wrap .checkbox-container {
                display: flex;
                align-items: center;
                margin: 10px 0;
            }

            .whatsapp-notifier-wrap input[type="checkbox"] {
                margin-right: 10px;
                width: 18px;
                height: 18px;
            }

            .whatsapp-notifier-wrap .description {
                color: #646970;
                font-size: 13px;
                margin-top: 8px;
                font-style: italic;
            }

            .whatsapp-notifier-wrap code {
                background: #f0f0f1;
                padding: 4px 8px;
                border-radius: 4px;
                font-size: 13px;
                color: #1d2327;
                display: inline-block;
                margin: 5px;
            }

            .whatsapp-notifier-wrap .submit {
                margin-top: 20px;
                padding-top: 20px;
                border-top: 1px solid #e2e4e7;
            }

            .whatsapp-notifier-wrap .button-primary {
                background: #2271b1;
                border-color: #2271b1;
                color: #fff;
                padding: 8px 25px;
                height: auto;
                font-size: 14px;
                font-weight: 500;
                border-radius: 6px;
                transition: all 0.3s ease;
            }

            .whatsapp-notifier-wrap .button-primary:hover {
                background: #135e96;
                border-color: #135e96;
                transform: translateY(-1px);
            }

            .whatsapp-notifier-wrap .button-primary:active {
                transform: translateY(0);
                background: #135e96;
                border-color: #135e96;
                box-shadow: inset 0 2px 4px rgba(0,0,0,0.1);
            }

            .whatsapp-notifier-wrap .variables-container {
                background: #f8f9fa;
                padding: 15px;
                border-radius: 6px;
                margin: 10px 0;
                border: 1px dashed #ccd0d4;
            }

            @media screen and (max-width: 782px) {
                .whatsapp-notifier-wrap .form-table th {
                    padding: 15px 10px;
                    width: 100%;
                    display: block;
                }
                
                .whatsapp-notifier-wrap .form-table td {
                    padding: 10px;
                    display: block;
                }
                
                .whatsapp-notifier-wrap input[type="text"],
                .whatsapp-notifier-wrap input[type="password"],
                .whatsapp-notifier-wrap textarea {
                    max-width: 100%;
                }
            }
        </style>
        <?php
    }

    public function handle_status_update($meta_id, $post_id, $meta_key, $meta_value) {
        if ($meta_key == 'order_status') {
            error_log('WhatsApp Notifier: Status atualizado para ' . $meta_value . ' no pedido ' . $post_id);
            $this->process_order_notification($post_id, $meta_value);
        }
    }

    public function add_admin_menu() {
        add_menu_page(
            'Plug Send API',
            'PlugSend API Delivery',
            'manage_options',
            'whatsapp-notifier',
            array($this, 'render_settings_page'),
            'dashicons-whatsapp'
        );
    }

    public function register_settings() {
        register_setting('whatsapp_notifier_settings', 'whatsapp_api_host');
        register_setting('whatsapp_notifier_settings', 'whatsapp_connection_key');
        register_setting('whatsapp_notifier_settings', 'whatsapp_bearer_token');
        register_setting('whatsapp_notifier_settings', 'whatsapp_message_template');
        register_setting('whatsapp_notifier_settings', 'whatsapp_disable_new_order');
    }

    public function render_settings_page() {
        ?>
        <div class="wrap whatsapp-notifier-wrap">
            <h1>Configurações da API Plug Send para delivery</h1>
            <form method="post" action="options.php">
                <?php
                settings_fields('whatsapp_notifier_settings');
                ?>
                
                <h2>Configurações da API</h2>
                <table class="form-table">
                    <tr>
                        <th scope="row">Host da API</th>
                        <td>
                            <input type="text" name="whatsapp_api_host" value="<?php echo esc_attr(get_option('whatsapp_api_host')); ?>" class="regular-text">
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">Connection Key</th>
                        <td>
                            <input type="text" name="whatsapp_connection_key" value="<?php echo esc_attr(get_option('whatsapp_connection_key')); ?>" class="regular-text">
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">Bearer Token</th>
                        <td>
                            <input type="password" name="whatsapp_bearer_token" value="<?php echo esc_attr(get_option('whatsapp_bearer_token')); ?>" class="regular-text">
                        </td>
                    </tr>
                </table>

                <h2>Configurações de Notificação</h2>
                <table class="form-table">
                    <tr>
                        <th scope="row">Desabilitar notificação de Pedido Feito</th>
                        <td>
                            <div class="checkbox-container">
                                <input type="checkbox" name="whatsapp_disable_new_order" value="1" <?php checked(1, get_option('whatsapp_disable_new_order'), true); ?>>
                                <label>Não enviar notificação quando o status for "Pedido Feito"</label>
                            </div>
                            <p class="description">Quando marcado, as notificações não serão enviadas para pedidos novos.</p>
                        </td>
                    </tr>
                </table>

                <h2>Modelo da mensagem</h2>
                <div class="variables-container">
                    <p>Você pode usar as seguintes variáveis na mensagem:</p>
                    <code>{nome}</code>
                    <code>{pedido}</code>
                    <code>{endereco}</code>
                    <code>{bairro}</code>
                    <code>{produtos}</code>
                    <code>{total}</code>
                    <code>{pagamento}</code>
                    <code>{status}</code>
                </div>
                <table class="form-table">
                    <tr>
                        <th scope="row">Mensagem</th>
                        <td>
                            <textarea name="whatsapp_message_template" rows="6" cols="50" class="large-text"><?php echo esc_textarea(get_option('whatsapp_message_template')); ?></textarea>
                        </td>
                    </tr>
                </table>

                <?php submit_button('Salvar Configurações'); ?>
            </form>
        </div>
        <?php
    }

    // ... (resto dos métodos permanecem iguais)

    private function process_message_variables($message, $order_data) {
        $replacements = array(
            '{nome}' => $order_data['customer_name'],
            '{pedido}' => $order_data['order_number'],
            '{endereco}' => $order_data['customer_address'],
            '{bairro}' => $order_data['neighborhood'],
            '{produtos}' => $order_data['product_names'],
            '{total}' => $order_data['total_price'],
            '{pagamento}' => $order_data['payment_method'],
            '{status}' => $order_data['status_label']
        );

        return str_replace(array_keys($replacements), array_values($replacements), $message);
    }

    private function send_whatsapp_message($phone_number, $message) {
        $host = get_option('whatsapp_api_host');
        $connection_key = get_option('whatsapp_connection_key');
        $token = get_option('whatsapp_bearer_token');

        if (empty($host) || empty($connection_key) || empty($token)) {
            error_log('WhatsApp Notifier: Configurações da API não definidas.');
            return false;
        }

        // Formata o número do telefone
        $phone_number = preg_replace('/\D/', '', $phone_number);
        if (strlen($phone_number) <= 11) {
            $phone_number = '55' . $phone_number;
        }

        error_log('WhatsApp Notifier: Tentando enviar mensagem para ' . $phone_number);

        $api_url = "https://{$host}/message/sendText?connectionKey={$connection_key}";

        $response = wp_remote_post($api_url, array(
            'headers' => array(
                'Content-Type' => 'application/json',
                'Authorization' => 'Bearer ' . $token
            ),
            'body' => json_encode(array(
                'phoneNumber' => $phone_number,
                'message' => $message
            )),
            'timeout' => 30
        ));

        if (is_wp_error($response)) {
            error_log('WhatsApp Notifier: Erro ao enviar mensagem - ' . $response->get_error_message());
            return false;
        }

        $response_code = wp_remote_retrieve_response_code($response);
        $response_body = wp_remote_retrieve_body($response);
        error_log('WhatsApp Notifier: Resposta da API - Status: ' . $response_code . ', Body: ' . $response_body);

        return $response_code === 200;
    }

    private function get_order_items($order_id) {
        $items = get_post_meta($order_id, 'myd_order_items', true);
        $product_names = array();
        if (!empty($items) && is_array($items)) {
            foreach ($items as $item) {
                if (isset($item['quantity']) && isset($item['product_name'])) {
                    $product_names[] = $item['quantity'] . 'x ' . $item['product_name'];
                }
            }
        }
        return implode(', ', $product_names);
    }

    private function process_order_notification($order_id, $new_status = null) {
        if (!$order_id) {
            error_log('WhatsApp Notifier: Order ID inválido');
            return;
        }

        // Usa o novo status passado como parâmetro, se disponível
        $order_status = $new_status !== null ? $new_status : get_post_meta($order_id, 'order_status', true);
        error_log('WhatsApp Notifier: Status original recebido: ' . $order_status);
        
        // Normaliza o status (remove espaços extras e converte para minúsculas)
        $status_key = trim(strtolower($order_status));

        // Verifica se deve ignorar notificação de pedido novo
        if ($status_key === 'new' && get_option('whatsapp_disable_new_order')) {
            error_log('WhatsApp Notifier: Notificação de Pedido Feito está desabilitada. Ignorando envio.');
            return;
        }
        
        // Obter o rótulo do status
        $status_label = isset($this->status_labels[$status_key]) ? $this->status_labels[$status_key] : $order_status;

        error_log('WhatsApp Notifier: Status key: ' . $status_key . ', Label final: ' . $status_label);

        // Obter o template da mensagem
        $message_template = get_option('whatsapp_message_template');
        if (empty($message_template)) {
            error_log('WhatsApp Notifier: Template de mensagem não configurado');
            return;
        }

        // Preparar dados do pedido
        $order_data = array(
            'order_number' => $order_id,
            'customer_name' => get_post_meta($order_id, 'order_customer_name', true),
            'customer_phone' => get_post_meta($order_id, 'customer_phone', true),
            'customer_address' => get_post_meta($order_id, 'order_address', true) . ', ' .
                               get_post_meta($order_id, 'order_address_number', true) . ' | ' .
                               get_post_meta($order_id, 'order_address_comp', true),
            'neighborhood' => get_post_meta($order_id, 'order_neighborhood', true),
            'product_names' => $this->get_order_items($order_id),
            'total_price' => 'R$' . get_post_meta($order_id, 'order_total', true),
            'payment_method' => get_post_meta($order_id, 'order_payment_method', true),
            'status_label' => $status_label
        );

        // Processar a mensagem com as variáveis
        $message = $this->process_message_variables($message_template, $order_data);

        // Enviar a mensagem
        $result = $this->send_whatsapp_message($order_data['customer_phone'], $message);

        if ($result) {
            error_log('WhatsApp Notifier: Mensagem enviada com sucesso para o pedido ' . $order_id);
        } else {
            error_log('WhatsApp Notifier: Falha ao enviar mensagem para o pedido ' . $order_id);
        }
    }
}

// Inicializa o plugin
function init_whatsapp_order_notifier() {
    return WhatsAppOrderNotifier::get_instance();
}

add_action('plugins_loaded', 'init_whatsapp_order_notifier');